#line 1 "conffile.yy.c"

#line 3 "conffile.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define router_yy_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer router_yy_create_buffer
#endif

#ifdef yy_delete_buffer
#define router_yy_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer router_yy_delete_buffer
#endif

#ifdef yy_scan_buffer
#define router_yy_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer router_yy_scan_buffer
#endif

#ifdef yy_scan_string
#define router_yy_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string router_yy_scan_string
#endif

#ifdef yy_scan_bytes
#define router_yy_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes router_yy_scan_bytes
#endif

#ifdef yy_init_buffer
#define router_yy_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer router_yy_init_buffer
#endif

#ifdef yy_flush_buffer
#define router_yy_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer router_yy_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define router_yy_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state router_yy_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define router_yy_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer router_yy_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define router_yypush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state router_yypush_buffer_state
#endif

#ifdef yypop_buffer_state
#define router_yypop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state router_yypop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define router_yyensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack router_yyensure_buffer_stack
#endif

#ifdef yylex
#define router_yylex_ALREADY_DEFINED
#else
#define yylex router_yylex
#endif

#ifdef yyrestart
#define router_yyrestart_ALREADY_DEFINED
#else
#define yyrestart router_yyrestart
#endif

#ifdef yylex_init
#define router_yylex_init_ALREADY_DEFINED
#else
#define yylex_init router_yylex_init
#endif

#ifdef yylex_init_extra
#define router_yylex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra router_yylex_init_extra
#endif

#ifdef yylex_destroy
#define router_yylex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy router_yylex_destroy
#endif

#ifdef yyget_debug
#define router_yyget_debug_ALREADY_DEFINED
#else
#define yyget_debug router_yyget_debug
#endif

#ifdef yyset_debug
#define router_yyset_debug_ALREADY_DEFINED
#else
#define yyset_debug router_yyset_debug
#endif

#ifdef yyget_extra
#define router_yyget_extra_ALREADY_DEFINED
#else
#define yyget_extra router_yyget_extra
#endif

#ifdef yyset_extra
#define router_yyset_extra_ALREADY_DEFINED
#else
#define yyset_extra router_yyset_extra
#endif

#ifdef yyget_in
#define router_yyget_in_ALREADY_DEFINED
#else
#define yyget_in router_yyget_in
#endif

#ifdef yyset_in
#define router_yyset_in_ALREADY_DEFINED
#else
#define yyset_in router_yyset_in
#endif

#ifdef yyget_out
#define router_yyget_out_ALREADY_DEFINED
#else
#define yyget_out router_yyget_out
#endif

#ifdef yyset_out
#define router_yyset_out_ALREADY_DEFINED
#else
#define yyset_out router_yyset_out
#endif

#ifdef yyget_leng
#define router_yyget_leng_ALREADY_DEFINED
#else
#define yyget_leng router_yyget_leng
#endif

#ifdef yyget_text
#define router_yyget_text_ALREADY_DEFINED
#else
#define yyget_text router_yyget_text
#endif

#ifdef yyget_lineno
#define router_yyget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno router_yyget_lineno
#endif

#ifdef yyset_lineno
#define router_yyset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno router_yyset_lineno
#endif

#ifdef yyget_column
#define router_yyget_column_ALREADY_DEFINED
#else
#define yyget_column router_yyget_column
#endif

#ifdef yyset_column
#define router_yyset_column_ALREADY_DEFINED
#else
#define yyset_column router_yyset_column
#endif

#ifdef yywrap
#define router_yywrap_ALREADY_DEFINED
#else
#define yywrap router_yywrap
#endif

#ifdef yyget_lval
#define router_yyget_lval_ALREADY_DEFINED
#else
#define yyget_lval router_yyget_lval
#endif

#ifdef yyset_lval
#define router_yyset_lval_ALREADY_DEFINED
#else
#define yyset_lval router_yyset_lval
#endif

#ifdef yyalloc
#define router_yyalloc_ALREADY_DEFINED
#else
#define yyalloc router_yyalloc
#endif

#ifdef yyrealloc
#define router_yyrealloc_ALREADY_DEFINED
#else
#define yyrealloc router_yyrealloc
#endif

#ifdef yyfree
#define router_yyfree_ALREADY_DEFINED
#else
#define yyfree router_yyfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define router_yywrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 109
#define YY_END_OF_BUFFER 110
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[559] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  110,  108,
      103,  104,  108,  107,  108,  108,  108,  108,  108,  108,
      108,  108,  108,  108,  108,  108,  108,  108,  108,  108,
      108,  108,  108,  105,  108,  108,  108,  108,  108,  108,
      108,  108,  108,  108,  108,  108,  108,  108,  108,  108,
      108,  108,  108,  108,  108,  108,  108,  108,  101,  101,
       99,   98,  101,  101,  108,   97,  106,  105,   25,  106,
      106,  106,  106,  106,  106,  106,  106,  106,  106,   27,

      106,  106,  106,  106,  106,  106,  106,  106,  106,  103,
      104,    0,  102,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   35,    0,    0,  105,    0,   46,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   50,
        0,    0,    0,    0,    0,   68,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  101,  101,  101,  100,  106,  106,
      105,  106,  106,  106,   12,  106,  106,  106,  106,  106,
      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,

      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   30,    0,    0,
        0,    0,    0,    0,    0,   62,    0,   56,    0,    0,
       49,    0,   58,    0,    0,   60,    0,    0,    0,    0,
        0,   54,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   94,    0,
       93,    0,    0,  106,  106,  106,  106,   22,  106,  106,
      106,  106,   24,  106,  106,   15,  106,  106,   14,  106,
      106,  106,  106,  106,  106,   89,  106,  106,  106,   91,

      106,    0,    0,    0,    0,    0,    0,   70,    0,    0,
        0,    0,   11,    0,    0,    0,   31,   29,    0,   34,
       37,    0,   39,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   69,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       82,    0,   81,    0,    0,   84,   95,  106,  106,  106,
       21,  106,  106,  106,  106,  106,   37,  106,  106,   16,
      106,  106,   34,  106,  106,   88,  106,  106,  106,  106,
        0,    0,    0,    0,   26,    0,    0,    0,    0,    0,
        0,    0,    0,   32,   33,   44,    0,    0,    0,   55,

        0,    0,    0,    0,    0,    0,    0,   47,    0,    0,
        0,    0,   67,    0,   78,    0,   74,    0,    0,   76,
        0,    0,    0,   92,  106,  106,  106,  106,   20,   13,
      106,  106,  106,  106,  106,   32,  106,   41,   87,   92,
      106,  106,    0,    0,    0,   83,    0,    0,    3,    0,
        0,    0,    0,    0,    0,   51,    0,   43,    0,   63,
       48,    0,    0,    0,   66,    0,    0,    0,    0,    0,
        0,   80,    0,   73,    0,  106,  106,  106,  106,   23,
       18,  106,    5,  106,   90,  106,    0,    1,   96,   38,
        0,    0,    0,    0,    2,    0,   61,   52,   57,   59,

        0,   42,   53,    0,    0,    0,    0,    0,   75,    0,
      106,   10,  106,  106,  106,  106,  106,    0,    0,    0,
        4,    7,    0,    0,    0,   65,    0,   77,   79,   85,
      106,   17,  106,  106,   28,  106,   40,    0,    6,    0,
        0,   45,    0,   36,  106,   19,   86,   72,    0,   64,
       71,  106,    0,   64,    9,    0,    8,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    5,    6,    7,    7,    7,    1,    7,
        7,    8,    7,    7,    7,    7,    7,    9,   10,    9,
        9,   11,    9,    9,    9,    9,    9,    7,   12,    7,
       13,    7,    7,    1,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,   14,    7,    7,   15,    1,   16,   17,   18,   19,

       20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
       30,   31,    7,   32,   33,   34,   35,   36,   37,   38,
       39,   40,    7,    7,    7,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[41] =
    {   0,
        1,    1,    2,    1,    3,    1,    4,    4,    4,    4,
        4,    1,    1,    5,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4
    } ;

static const flex_int16_t yy_base[567] =
    {   0,
        0,   32,   64,    0,   74,    0,    1,   21,  101,    0,
       36,   63,  130,    0,  152,    0,  186,  199,  213,    0,
      246,    0,  139,  149,   39,   41,  275,    0,  855,  856,
        3,  851,  850,  856,  830,  824,  821,  825,  832,  827,
        9,  817,  829,  136,  809,  811,  815,  811,  810,   21,
      809,  805,  808,    0,   66,  801,    1,   24,  100,  814,
      814,   63,  103,  817,  800,  797,  809,  799,  792,  798,
      794,  805,   43,  800,  799,  790,   86,   84,    0,   11,
      818,  856,  139,    0,    0,  856,  806,  185,  856,  101,
       91,    0,  162,  247,  258,  129,  255,  278,  272,  805,

      144,  164,    7,  100,  166,  253,  286,  287,  244,  205,
      815,  814,  856,  794,  780,  796,  780,  778,  774,  781,
      793,  769,  775,  782,  778,  768,  771,  774,  771,  767,
      777,  763,  768,  766,  856,  771,  760,  312,  759,  856,
      188,  774,  757,   23,  771,  758,  750,  768,  245,  856,
      754,  127,  279,  757,  756,  856,  751,  758,  765,  746,
      744,  758,  743,  756,  742,  285,  757,  739,  743,  741,
      739,  738,  737,  743,    0,  258,  321,  856,  752,  311,
      318,  317,  183,  316,  751,  290,  323,  322,  325,  327,
      328,  285,  329,  331,  332,  333,  334,  336,  337,  338,

      339,  342,  340,  347,  361,  360,  348,  363,  356,  366,
      732,  730,  735,  727,  742,  727,  739,  723,  741,  738,
      727,  733,  742,  714,  719,  718,  728,  856,  713,  727,
      714,  715,  713,  722,  709,  856,  714,  856,  708,  709,
      856,  713,  712,  711,  715,  709,  714,  701,  711,  697,
      709,  699,  706,  701,  690,  689,  702,  692,  688,  699,
      697,  697,  686,  696,  686,  690,  692,  677,  856,  690,
      856,  671,    0,  367,  370,  373,  374,  694,  375,  376,
      378,  377,  693,  381,  379,  692,  382,  383,  691,  384,
      387,   72,  393,  388,  395,  690,  399,  400,  401,  689,

      402,  682,  667,  665,  679,  675,  673,  856,  672,  665,
      664,  663,  856,  676,  675,  675,  856,  856,  669,  856,
      856,  666,  856,  655,  670,  665,  649,  649,  650,  653,
      664,  652,  650,  657,  647,  856,  641,  654,  657,  639,
      655,  650,  645,  636,  633,  627,  633,  640,  629,  633,
      856,  637,  856,  632,  629,  856,  856,  644,  404,  405,
      643,  408,  410,  411,  413,  414,  642,  421,  415,  641,
      426,  424,  640,  428,  429,  639,  432,  435,  436,  438,
      630,  631,  631,  620,  856,  614,  614,  625,  616,  608,
      628,  610,  620,  856,  856,  856,  618,  605,  604,  856,

      617,  601,  606,  614,  598,  603,  612,  856,  594,  597,
      594,  598,  856,  593,  856,  605,  856,  588,  585,  856,
      603,  587,  590,  856,  450,  252,  442,  443,  605,  604,
      441,  444,  448,  446,  449,  603,  458,  602,  601,  600,
      455,  461,  597,  580,  591,  856,  590,  575,  856,  593,
      587,  588,  586,  575,  583,  856,  582,  856,  573,  856,
      856,  572,  565,  565,  856,  558,  580,  577,  560,  561,
      576,  856,  558,  856,  571,  465,  464,  466,  470,  575,
      574,  467,  573,  473,  572,  474,  551,  856,  856,  856,
      560,  565,  550,  558,  856,  544,  856,  856,  856,  856,

      555,  856,  856,  550,  557,  552,  542,  547,  856,  553,
      475,  558,  476,  477,  484,  479,  486,  551,  552,  546,
      856,  856,  558,  540,  535,  856,  547,  856,  856,  856,
      489,  550,  491,  487,  549,  492,  856,  522,  856,  531,
      526,  856,  490,  508,  494,  506,  505,  856,  502,  503,
      856,  496,  348,  518,  150,  100,  856,  856,  529,  534,
      539,  544,  548,  553,  555,  557
    } ;

static const flex_int16_t yy_def[567] =
    {   0,
      559,  559,  559,    3,    3,    5,    3,    3,    3,    9,
        3,    3,    3,   13,    3,   15,  560,  560,  558,   19,
       19,   21,   21,   21,   21,   21,   21,   27,  558,  558,
      558,  558,  561,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  562,  562,
      558,  558,  563,  562,  564,  558,  565,  565,  558,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,

      565,  565,  565,  565,  565,  565,  565,  565,  565,  558,
      558,  561,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  562,  562,  563,  558,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,

      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  566,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,

      565,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  566,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,

      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  566,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  565,  565,  565,  565,
      565,  565,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  565,  565,  565,  565,  565,
      565,  565,  565,  565,  565,  565,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,

      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      565,  565,  565,  565,  565,  565,  565,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      565,  565,  565,  565,  565,  565,  558,  558,  558,  558,
      558,  558,  558,  565,  565,  565,  565,  558,  558,  558,
      558,  565,  558,  558,  565,  558,  558,    0,  558,  558,
      558,  558,  558,  558,  558,  558
    } ;

static const flex_int16_t yy_nxt[897] =
    {   0,
      558,   31,   32,   31,  110,   33,  110,  558,  138,  138,
      138,   34,  176,  180,  176,   35,   30,   36,   30,  558,
      180,   30,  202,   37,   53,   30,   38,   39,  120,  143,
      144,   40,   41,   31,   32,   31,   30,   33,   30,  184,
      133,   30,  121,   34,   53,   30,   87,   35,   87,   36,
      239,   30,  145,   30,  134,   37,   30,  240,   38,   39,
       30,  146,  166,   40,   41,   31,   32,   31,   66,   33,
       87,   87,   87,   87,   87,   34,   87,  167,   30,   42,
       30,   43,  152,   30,   44,  180,  139,   30,   45,   30,
      373,   30,   46,   47,   30,   66,  153,  154,   30,  140,

       48,  141,  173,  171,  180,   49,   50,   51,   52,   54,
       54,   54,  174,  180,  180,  147,   55,   56,   57,  148,
       58,   30,  557,  149,  172,   30,  155,  182,   59,  183,
       60,   61,  156,   62,   63,  203,   64,   65,   54,   54,
       54,  113,  180,  112,  248,   67,   87,   68,  190,   69,
       30,  124,  112,   70,   30,  249,   87,  180,  104,  125,
       71,   72,   73,  180,  126,  127,   74,   30,  104,   30,
       87,   87,   30,  200,   87,  180,   30,  180,   75,  180,
       87,   87,   76,  201,   87,   77,   78,   80,   81,   80,
       82,   83,  185,  181,  181,  181,  180,   84,  180,   85,

       80,   81,   80,   82,   83,  204,  110,  235,  110,  236,
       84,  275,   85,   30,   31,   32,   31,   86,   33,   87,
       87,   88,   88,   88,   34,   89,   87,   87,   87,   90,
       87,   91,   87,   87,   92,   87,   93,   87,   87,   94,
       87,   87,   87,   95,   96,   97,   98,   99,   87,   87,
       87,   87,   87,  100,   87,   87,   87,  180,   30,  176,
      180,  176,   87,  245,   87,  180,  180,   87,  180,   87,
      186,  180,   87,  246,  476,  210,   87,  101,  102,   87,
       87,  103,   87,  191,  188,  180,  187,  192,  193,  189,
      198,  180,  205,  194,  250,  195,  105,  251,  180,  180,

      180,  106,  263,  180,  199,  107,   87,  108,  109,  196,
       87,  283,  206,  264,  273,  208,  197,  207,  277,  209,
      138,  138,  138,  113,  180,  112,  181,  181,  181,  180,
      180,  180,  274,  278,  112,  180,  180,  279,  180,  276,
      180,  180,  180,  282,  180,  180,  180,  180,  287,  180,
      180,  180,  180,  180,  280,  180,  290,  281,  284,  294,
      180,  180,  286,  285,  288,  556,  289,  292,  293,  180,
      295,  296,  291,  180,  180,  297,  180,  298,  299,  180,
      180,  301,  300,  180,  359,  360,  180,  180,  180,  180,
      180,  180,  180,  362,  180,  180,  180,  180,  363,  371,

      180,  180,  370,  361,  365,  368,  180,  366,  180,  364,
      369,  367,  180,  180,  180,  180,  374,  180,  180,  375,
      372,  180,  377,  180,  180,  376,  180,  180,  180,  426,
      380,  379,  427,  378,  180,  428,  431,  180,  429,  180,
      430,  180,  180,  436,  432,  180,  437,  434,  180,  180,
      433,  180,  435,  273,  180,  180,  180,  180,  479,  180,
      439,  180,  180,  425,  440,  477,  441,  438,  180,  481,
      442,  180,  478,  484,  180,  483,  482,  180,  180,  180,
      180,  512,  480,  180,  513,  514,  180,  180,  180,  180,
      180,  486,  180,  485,  511,  532,  515,  180,  535,  180,

      180,  531,  180,  517,  180,  180,  516,  180,  544,  180,
      533,  554,  554,  554,  545,  534,  553,  536,  180,  180,
      546,  180,  551,  552,  555,  547,  554,  554,  554,   30,
       30,   30,   30,   30,   79,   79,   79,   79,   79,  112,
      112,  112,  112,  112,  175,  550,  549,  175,  177,  177,
      177,  177,  177,  178,  548,  178,  178,  178,  179,  179,
      358,  358,  180,  180,  543,  542,  541,  540,  539,  538,
      537,  180,  530,  529,  528,  527,  526,  525,  524,  523,
      522,  521,  520,  519,  518,  180,  180,  180,  180,  510,
      509,  508,  507,  506,  505,  504,  503,  502,  501,  500,

      499,  498,  497,  496,  495,  494,  493,  492,  491,  490,
      489,  488,  487,  180,  180,  180,  180,  180,  180,  475,
      474,  473,  472,  471,  470,  469,  468,  467,  466,  465,
      464,  463,  462,  461,  460,  459,  458,  457,  456,  455,
      454,  453,  452,  451,  450,  449,  448,  447,  446,  445,
      444,  443,  180,  180,  180,  180,  180,  425,  424,  423,
      422,  421,  420,  419,  418,  417,  416,  415,  414,  413,
      412,  411,  410,  409,  408,  407,  406,  405,  404,  403,
      402,  401,  400,  399,  398,  397,  396,  395,  394,  393,
      392,  391,  390,  389,  388,  387,  386,  385,  384,  383,

      382,  381,  180,  180,  180,  180,  180,  180,  357,  356,
      355,  354,  353,  352,  351,  350,  349,  348,  347,  346,
      345,  344,  343,  342,  341,  340,  339,  338,  337,  336,
      335,  334,  333,  332,  331,  330,  329,  328,  327,  326,
      325,  324,  323,  322,  321,  320,  319,  318,  317,  316,
      315,  314,  313,  312,  311,  310,  309,  308,  307,  306,
      305,  304,  303,  302,  180,  180,  272,  271,  270,  269,
      268,  267,  266,  265,  262,  261,  260,  259,  258,  257,
      256,  255,  254,  253,  252,  247,  244,  243,  242,  241,
      238,  237,  234,  233,  232,  231,  230,  229,  228,  227,

      226,  225,  224,  223,  222,  221,  220,  219,  218,  217,
      216,  215,  214,  213,  212,  211,  113,  111,  180,  180,
      111,  170,  169,  168,  165,  164,  163,  162,  161,  160,
      159,  158,  157,  151,  150,  142,  137,  136,  135,  132,
      131,  130,  129,  128,  123,  122,  119,  118,  117,  116,
      115,  114,  113,  111,  558,   29,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558

    } ;

static const flex_int16_t yy_chk[897] =
    {   0,
        0,    1,    1,    1,   31,    1,   31,    0,   54,   54,
       54,    1,   80,   92,   80,    1,    7,    1,    7,    0,
      103,    7,  103,    1,    7,    7,    1,    1,   41,   57,
       57,    1,    1,    2,    2,    2,    8,    2,    8,   92,
       50,    8,   41,    2,    8,    8,   25,    2,   26,    2,
      144,   11,   58,   11,   50,    2,   11,  144,    2,    2,
       11,   58,   73,    2,    2,    3,    3,    3,   11,    3,
       25,   25,   26,   26,   25,    3,   26,   73,   12,    3,
       12,    3,   62,   12,    3,  292,   55,   12,    3,    5,
      292,    5,    5,    5,    5,   12,   62,   62,    5,   55,

        5,   55,   78,   77,   91,    5,    5,    5,    5,    9,
        9,    9,   78,  104,   90,   59,    9,    9,    9,   59,
        9,    9,  556,   59,   77,    9,   63,   90,    9,   91,
        9,    9,   63,    9,    9,  104,    9,    9,   13,   13,
       13,   83,   96,   83,  152,   13,   23,   13,   96,   13,
       13,   44,   83,   13,   13,  152,   24,  101,   23,   44,
       13,   13,   13,  555,   44,   44,   13,   15,   24,   15,
       23,   23,   15,  101,   23,   93,   15,  102,   15,  105,
       24,   24,   15,  102,   24,   15,   15,   17,   17,   17,
       17,   17,   93,   88,   88,   88,  183,   17,   88,   17,

       18,   18,   18,   18,   18,  105,  110,  141,  110,  141,
       18,  183,   18,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   21,   21,   21,   21,  109,   21,  176,
       94,  176,   21,  149,   21,  426,  106,   21,   97,   21,
       94,   95,   21,  149,  426,  109,   21,   21,   21,   21,
       21,   21,   27,   97,   95,   99,   94,   97,   97,   95,
       99,   98,  106,   97,  153,   98,   27,  153,  192,  107,

      108,   27,  166,  186,   99,   27,   27,   27,   27,   98,
       27,  192,  107,  166,  180,  108,   98,  107,  186,  108,
      138,  138,  138,  177,  180,  177,  181,  181,  181,  184,
      182,  181,  182,  187,  177,  188,  187,  188,  189,  184,
      190,  191,  193,  191,  194,  195,  196,  197,  196,  198,
      199,  200,  201,  203,  189,  202,  199,  190,  193,  203,
      204,  207,  195,  194,  197,  553,  198,  201,  202,  209,
      204,  205,  200,  206,  205,  206,  208,  207,  208,  210,
      274,  210,  209,  275,  274,  275,  276,  277,  279,  280,
      282,  281,  285,  277,  284,  287,  288,  290,  279,  290,

      291,  294,  288,  276,  281,  285,  293,  282,  295,  280,
      287,  284,  297,  298,  299,  301,  293,  359,  360,  294,
      291,  362,  297,  363,  364,  295,  365,  366,  369,  359,
      301,  299,  360,  298,  368,  362,  365,  372,  363,  371,
      364,  374,  375,  372,  366,  377,  374,  369,  378,  379,
      368,  380,  371,  425,  431,  427,  428,  432,  431,  434,
      377,  433,  435,  425,  378,  427,  379,  375,  441,  433,
      380,  437,  428,  437,  442,  435,  434,  477,  476,  478,
      482,  477,  432,  479,  478,  479,  484,  486,  511,  513,
      514,  442,  516,  441,  476,  513,  482,  515,  516,  517,

      534,  511,  531,  486,  533,  536,  484,  545,  531,  552,
      514,  550,  550,  550,  533,  515,  549,  517,  547,  546,
      534,  544,  543,  545,  552,  536,  554,  554,  554,  559,
      559,  559,  559,  559,  560,  560,  560,  560,  560,  561,
      561,  561,  561,  561,  562,  541,  540,  562,  563,  563,
      563,  563,  563,  564,  538,  564,  564,  564,  565,  565,
      566,  566,  535,  532,  527,  525,  524,  523,  520,  519,
      518,  512,  510,  508,  507,  506,  505,  504,  501,  496,
      494,  493,  492,  491,  487,  485,  483,  481,  480,  475,
      473,  471,  470,  469,  468,  467,  466,  464,  463,  462,

      459,  457,  455,  454,  453,  452,  451,  450,  448,  447,
      445,  444,  443,  440,  439,  438,  436,  430,  429,  423,
      422,  421,  419,  418,  416,  414,  412,  411,  410,  409,
      407,  406,  405,  404,  403,  402,  401,  399,  398,  397,
      393,  392,  391,  390,  389,  388,  387,  386,  384,  383,
      382,  381,  376,  373,  370,  367,  361,  358,  355,  354,
      352,  350,  349,  348,  347,  346,  345,  344,  343,  342,
      341,  340,  339,  338,  337,  335,  334,  333,  332,  331,
      330,  329,  328,  327,  326,  325,  324,  322,  319,  316,
      315,  314,  312,  311,  310,  309,  307,  306,  305,  304,

      303,  302,  300,  296,  289,  286,  283,  278,  272,  270,
      268,  267,  266,  265,  264,  263,  262,  261,  260,  259,
      258,  257,  256,  255,  254,  253,  252,  251,  250,  249,
      248,  247,  246,  245,  244,  243,  242,  240,  239,  237,
      235,  234,  233,  232,  231,  230,  229,  227,  226,  225,
      224,  223,  222,  221,  220,  219,  218,  217,  216,  215,
      214,  213,  212,  211,  185,  179,  174,  173,  172,  171,
      170,  169,  168,  167,  165,  164,  163,  162,  161,  160,
      159,  158,  157,  155,  154,  151,  148,  147,  146,  145,
      143,  142,  139,  137,  136,  134,  133,  132,  131,  130,

      129,  128,  127,  126,  125,  124,  123,  122,  121,  120,
      119,  118,  117,  116,  115,  114,  112,  111,  100,   87,
       81,   76,   75,   74,   72,   71,   70,   69,   68,   67,
       66,   65,   64,   61,   60,   56,   53,   52,   51,   49,
       48,   47,   46,   45,   43,   42,   40,   39,   38,   37,
       36,   35,   33,   32,   29,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558

    } ;

/* Table of booleans, true if rule could match eol. */
static const flex_int32_t yy_rule_can_match_eol[110] =
    {   0,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 
    0, 0, 1, 0, 1, 0, 0, 0, 0, 0,     };

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "conffile.l"
#line 2 "conffile.l"
#include "allocator.h"
#include "conffile.h"
#include "conffile.tab.h"
#define YYSTYPE ROUTER_YYSTYPE

#define YY_DECL int router_yylex \
	(YYSTYPE *yylval_param, ROUTER_YYLTYPE *llocp, yyscan_t yyscanner, router *rtr, allocator *ralloc, allocator *palloc)
#define YY_USER_ACTION llocp->first_line = llocp->last_line = yylineno; \
	llocp->first_column = yycolumn; llocp->last_column = yycolumn+yyleng-1; \
	yycolumn += yyleng;
#define YY_USER_INIT yycolumn = 0; yylineno = 0;

int identstate = 0;
#line 1067 "conffile.yy.c"
#define YY_NO_INPUT 1

#line 1070 "conffile.yy.c"

#define INITIAL 0
#define cl 1
#define ma 2
#define re 3
#define ag 4
#define se 5
#define st 6
#define li 7
#define qu 8
#define idcl 9
#define idma 10
#define idag 11
#define idin 12
#define idli 13

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 31 "conffile.l"


#line 34 "conffile.l"
	char string_buf[1024];
	char *strbuf = NULL;

#line 1362 "conffile.yy.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 559 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 856 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 37 "conffile.l"
{
						identstate = cl;
						BEGIN(idcl);
						return crCLUSTER;
					}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 42 "conffile.l"
{
						identstate = idcl;
						BEGIN(idcl);
						return crFORWARD;
					}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 47 "conffile.l"
{
						identstate = idcl;
						BEGIN(idcl);
						return crANY_OF;
					}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 52 "conffile.l"
{
						identstate = idcl;
						BEGIN(idcl);
						return crFAILOVER;
					}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 57 "conffile.l"
return crUSEALL;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 58 "conffile.l"
{
						identstate = idcl;
						BEGIN(idcl);
						return crCARBON_CH;
					}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 63 "conffile.l"
{
						identstate = idcl;
						BEGIN(idcl);
						return crFNV1A_CH;
					}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 68 "conffile.l"
{
						identstate = idcl;
						BEGIN(idcl);
						return crJUMP_FNV1A_CH;
					}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 73 "conffile.l"
return crREPLICATION;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 74 "conffile.l"
return crDYNAMIC;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 75 "conffile.l"
{
						identstate = idcl;
						BEGIN(idcl);
						return crFILE;
					}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 80 "conffile.l"
return crIP;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 81 "conffile.l"
return crPROTO;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 82 "conffile.l"
return crUDP;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 83 "conffile.l"
return crTCP;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 84 "conffile.l"
return crTYPE;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 85 "conffile.l"
return crLINEMODE;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 86 "conffile.l"
return crSYSLOGMODE;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 87 "conffile.l"
return crTRANSPORT;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 88 "conffile.l"
return crPLAIN;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 89 "conffile.l"
return crGZIP;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 90 "conffile.l"
return crLZ4;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 91 "conffile.l"
return crSNAPPY;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 92 "conffile.l"
return crSSL;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 93 "conffile.l"
return '=';
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 95 "conffile.l"
{
						identstate = idma;
						BEGIN(idma);
						return crMATCH;
					}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 100 "conffile.l"
return '*';
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 101 "conffile.l"
{
						identstate = ma;
						BEGIN(idma);
						return crVALIDATE;
					}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 106 "conffile.l"
return crELSE;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 107 "conffile.l"
return crLOG;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 108 "conffile.l"
return crDROP;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 109 "conffile.l"
{
						BEGIN(ma);
						return crROUTE;
					}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 113 "conffile.l"
{	
						identstate = ma;
						BEGIN(idma);
						return crUSING;
					}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 118 "conffile.l"
{
						BEGIN(ma);
						return crSEND;
					}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 122 "conffile.l"
{
						identstate = idcl;
						BEGIN(idcl);
						return crTO;
					}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 127 "conffile.l"
return crBLACKHOLE;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 128 "conffile.l"
return crSTOP;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 130 "conffile.l"
{
						identstate = re;
						BEGIN(idma);
						return crREWRITE;
					}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 135 "conffile.l"
{
						identstate = re;
						BEGIN(idma);
						return crINTO;
					}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 141 "conffile.l"
{
						identstate = idag;
						BEGIN(idag);
						return crAGGREGATE;
					}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 146 "conffile.l"
{
						BEGIN(ag);
						return crEVERY;
					}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 150 "conffile.l"
return crSECONDS;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 151 "conffile.l"
return crEXPIRE;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 152 "conffile.l"
return crAFTER;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 153 "conffile.l"
return crTIMESTAMP;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 154 "conffile.l"
return crAT;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 155 "conffile.l"
return crSTART;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 156 "conffile.l"
return crMIDDLE;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 157 "conffile.l"
return crEND;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 158 "conffile.l"
return crOF;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 159 "conffile.l"
return crBUCKET;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 160 "conffile.l"
return crCOMPUTE;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 161 "conffile.l"
return crSUM;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 162 "conffile.l"
return crSUM;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 163 "conffile.l"
return crCOUNT;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 164 "conffile.l"
return crCOUNT;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 165 "conffile.l"
return crMAX;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 166 "conffile.l"
return crMAX;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 167 "conffile.l"
return crMIN;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 168 "conffile.l"
return crMIN;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 169 "conffile.l"
return crAVERAGE;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 170 "conffile.l"
return crAVERAGE;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 171 "conffile.l"
return crMEDIAN;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 172 "conffile.l"
{
						yylval_param->crINTVAL =
							atoi(yytext + strlen("percentile"));
						return crPERCENTILE;
					}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 177 "conffile.l"
return crVARIANCE;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 178 "conffile.l"
return crSTDDEV;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 179 "conffile.l"
return crWRITE;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 180 "conffile.l"
{
						identstate = ag;
						BEGIN(idag);
						return crTO;
					}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 185 "conffile.l"
{
						/* reuse the match logic for send to ... stop */
						BEGIN(ma);
						return crSEND;
					}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 191 "conffile.l"
{
						BEGIN(se);
						return crSEND;
					}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 195 "conffile.l"
{
						/* reuse the match logic for send to ... stop */
						BEGIN(ma);
						return crSTATISTICS;
					}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 201 "conffile.l"
{
						BEGIN(st);
						return crSTATISTICS;
					}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 205 "conffile.l"
return crSUBMIT;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 206 "conffile.l"
return crEVERY;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 207 "conffile.l"
return crSECONDS;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 208 "conffile.l"
return crRESET;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 209 "conffile.l"
return crCOUNTERS;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 210 "conffile.l"
return crAFTER;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 211 "conffile.l"
return crINTERVAL;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 212 "conffile.l"
return crPREFIX;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 213 "conffile.l"
{
						identstate = st;
						BEGIN(idag);
						return crWITH;
					}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 218 "conffile.l"
{
						/* reuse the match logic for send to ... stop */
						BEGIN(ma);
						return crSEND;
					}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 224 "conffile.l"
{
						BEGIN(li);
						return crLISTEN;
					}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 228 "conffile.l"
return crTYPE;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 229 "conffile.l"
{
						identstate = li;
						BEGIN(idli);
						return crLINEMODE;
					}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 234 "conffile.l"
return crTRANSPORT;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 235 "conffile.l"
return crPLAIN;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 236 "conffile.l"
{
						identstate = li;
						BEGIN(idli);
						return crGZIP;
					}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 241 "conffile.l"
{
						identstate = li;
						BEGIN(idli);
						return crLZ4;
					}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 246 "conffile.l"
{
						identstate = li;
						BEGIN(idli);
						return crSNAPPY;
					}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 251 "conffile.l"
{
						identstate = idli;
						BEGIN(idli);
						return crSSL;
					}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 256 "conffile.l"
{
						BEGIN(li);
						return crPROTO;
					}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 260 "conffile.l"
{
						identstate = li;
						BEGIN(idli);
						return crUDP;
					}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 265 "conffile.l"
{
						identstate = li;
						BEGIN(idli);
						return crTCP;
					}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 270 "conffile.l"
{
						identstate = li;
						BEGIN(idli);
						return crUNIX;
					}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 276 "conffile.l"
{
						identstate = INITIAL;
						BEGIN(idin);
						return crINCLUDE;
					}
	YY_BREAK
/* handle quoted strings */
case 97:
YY_RULE_SETUP
#line 283 "conffile.l"
{
						strbuf = string_buf;
						BEGIN(qu);
					}
	YY_BREAK

case 98:
YY_RULE_SETUP
#line 288 "conffile.l"
{
						if (strbuf == string_buf) {
							router_yyerror(llocp, NULL, rtr, ralloc, palloc,
									"empty string");
							yyterminate();
						}
						BEGIN(identstate);
						*strbuf = '\0';
						yylval_param->crSTRING = ra_strdup(palloc, string_buf);
						return crSTRING;
					}
	YY_BREAK
case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
#line 299 "conffile.l"
{
						router_yyerror(llocp, NULL, rtr, ralloc, palloc,
								"unterminated string");
						yyterminate();
					}
	YY_BREAK
case YY_STATE_EOF(qu):
#line 304 "conffile.l"
{
						router_yyerror(llocp, NULL, rtr, ralloc, palloc,
								"unterminated string");
						yyterminate();
					}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 309 "conffile.l"
{
						*strbuf++ = yytext[1];
						if (strbuf == string_buf + sizeof(string_buf)) {
							router_yyerror(llocp, NULL, rtr, ralloc, palloc,
									"string too large");
							yyterminate();
						}
					}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 317 "conffile.l"
{
						char *yptr = yytext;
						while (*yptr) {
							*strbuf++ = *yptr++;
							if (strbuf == string_buf + sizeof(string_buf)) {
								router_yyerror(llocp, NULL, rtr,
										ralloc, palloc, "string too large");
								yyterminate();
							}
						}
					}
	YY_BREAK

case 102:
/* rule 102 can match eol */
YY_RULE_SETUP
#line 330 "conffile.l"
{
						/* ignore for now
						yylval_param->crCOMMENT = ra_strdup(palloc, yytext);
						return crCOMMENT;
						*/
						yycolumn = 0;
						;
					}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 339 "conffile.l"
; /* whitespace */
	YY_BREAK
case 104:
/* rule 104 can match eol */
YY_RULE_SETUP
#line 340 "conffile.l"
yycolumn = 0;
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 341 "conffile.l"
{
						yylval_param->crINTVAL = atoi(yytext);
						return crINTVAL;
					}
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 345 "conffile.l"
{
						yylval_param->crSTRING = ra_strdup(palloc, yytext);
						BEGIN(identstate);
						return crSTRING;
					}
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 350 "conffile.l"
{ BEGIN(INITIAL); return ';'; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 351 "conffile.l"
{
						/* feed this back to the parser, it will give a
						 * nice error message */
						yylval_param->crSTRING = ra_strdup(palloc, yytext);
						return crUNEXPECTED;
					}
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 358 "conffile.l"
ECHO;
	YY_BREAK
#line 2184 "conffile.yy.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(cl):
case YY_STATE_EOF(ma):
case YY_STATE_EOF(re):
case YY_STATE_EOF(ag):
case YY_STATE_EOF(se):
case YY_STATE_EOF(st):
case YY_STATE_EOF(li):
case YY_STATE_EOF(idcl):
case YY_STATE_EOF(idma):
case YY_STATE_EOF(idag):
case YY_STATE_EOF(idin):
case YY_STATE_EOF(idli):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 559 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 559 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 558);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	if ( c == '\n' )
		
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 358 "conffile.l"


